declare("tgft_utils", {})
-- TGFT Price data Collector and reporter
--	Lisa201

tgft_utils.version = "1.56"

require( "iuplua" )
require( "iupluacontrols" )

dofile("tgftd_http.lua")
dofile("systems.lua")
dofile("json.lua")
dofile("ui.lua")

local DeBug = false
tgft_utils.passwd = nil
tgft_utils.user = nil
tgft_utils.unload = false
tgft_utils.TurboOn = false
tgft_utils.nodeid = 0
tgft_utils.objectid = 0
tgft_utils.keys = {}
tgft_utils.stations = {}

-------------------------------------------------------------	
-- Toggle Turbo on and off
-------------------------------------------------------------	
function turbotoggle()
if tgft_utils.TurboOn then
      gkinterface.GKProcessCommand('+turbo 1')
      gkinterface.GKProcessCommand('+turbo 0')
else
      gkinterface.GKProcessCommand('+turbo 0')
      gkinterface.GKProcessCommand('+turbo 1')
 end
	tgft_utils.TurboOn = not tgft_utils.TurboOn
end

-------------------------------------------------------------	
-- Toggle debug on and off
-------------------------------------------------------------	
function debugtoggle()
	DeBug = not DeBug
	if DeBug then print("debug on") else print("debug off") end
end

-------------------------------------------------------------	
-- Launch from the ship ---------------------------
-------------------------------------------------------------	
function tgft_utils.launch()
RequestLaunch() 
end

-------------------------------------------------------
-- Get Keys in your keychain
-------------------------------------------------------
function tgft_utils.Get_Keychain()
tgft_utils.keys = {}
for v = 1, GetNumKeysInKeychain(), 1 do
		local keyid, description, owner, timestamp, access, possessors, active = GetKeyInfo(tonumber(v))
		local key_data = {}
		if active then 
			Keychain.list(keyid, 
				function(isError, message)
				if (isError) then
					print("KEY ERROR:")
				else
					keyid, description, owner, timestamp, access, possessors, active = GetKeyInfo(tonumber(v))
				end
			end)
			local key_data = {ID = keyid, DESC = description, OWN = owner, ACTIVE = active, ACCESS = access, POSS = possessors }
			table.insert(tgft_utils.keys,key_data)
		end
	end
end

-------------------------------------------------------
-- Get a keys index number 
-------------------------------------------------------
function tgft_utils.GetKeyIndex(x)
	for i = 1, GetNumKeysInKeychain(), 1 do 
		local keyid, description, owner, timestamp, access, possessors, active = GetKeyInfo(tonumber(i))
		if (tonumber(keyid) == tonumber(x)) then return i end
	end
return -1 -- Not found in the list 
end

-------------------------------------------------------
-- Verify Key when you enter systems 
-------------------------------------------------------
function tgft_utils.VerifyDestination()
	local destsector = NavRoute.GetNextHop()
	local stationname = "None"
	if destsector==4019 then stationname = "Pelatus Mining Station" end
	if destsector==4317 then stationname = "Bractus IX Planetary Outpost" end
	if destsector==5753 then stationname = "CONQUERABLE STATION" end
	tgft_utils.Sector_Verified()
	if stationname == "None" then return end -- Normal sectors... just return
	
	for i = 1, #tgft_utils.keys, 1 do 
		local keyid, description, owner, timestamp, access, possessors, active = 
			GetKeyInfo(tonumber(tgft_utils.GetKeyIndex(tgft_utils.keys[i]["ID"])))
		if access then 
			for j = 1, # access, 1 do 
				--print("station:"..access[j][1].name)
				if (access[j][1].name==stationname) then
					--print("station2:"..access[j][1].name)
					if (access[j][2].candock) and (access[j][2].iff)then return end
				end
			end
		end
	end
	print("\127ff1010-- WARNING -- Key is NOT VALID for: "..stationname)
end 

-------------------------------------------------------
-- Verify faction standing before jumping to systems
-------------------------------------------------------
function tgft_utils.Sector_Verified()
	local destsector = NavRoute.GetNextHop()
	local systemid = GetSystemID(destsector)
	local faction = tgft_utils.System_Names[systemid][3]
	--if not tgft_utils.stations[2] then
		--tgft_utils.Init()
	--end
	
	for i = 1, #tgft_utils.stations[2], 1 do
		if (tonumber(tgft_utils.stations[2][i][1]) == destsector) then
			faction = tonumber(tgft_utils.stations[2][i][2])
			break;
		end
	end
	local destfaction = GetPlayerFactionStanding(faction, GetCharacterID()) / 32.768 -1000
	if destfaction < -600 then
		print("\127ff1010-- WARNING -- Faction Standing at Destination: "..destfaction)
	elseif destfaction < -550 then
		print("\127ff1010-- CAUTION -- Check Faction Standing.  Low at Destination!")
	end
end

-------------------------------------------------------
-- Saw a player in space
-------------------------------------------------------
function tgft_utils.SawPlayer(event, data)
	if not data then return end
 	local characteris = GetPlayerName(data)
 	local hischarid = data
 	if characteris == GetPlayerName(GetCharacterID()) then return end
  	local isNPC = (string.sub( characteris, 1, 1) == "*") or (string.match(characteris, "reading transponder"))
  	if isNPC then return end --Don't log bots...
 	local hisship = GetPrimaryShipNameOfPlayer(data) or "NO Ship"
 	local hisguild = GetGuildTag(data)
  	if DeBug then print("SawPlayer Event:"..event) end
 	if DeBug then print("Spotted: "..characteris.."   Ship:"..hisship) end
 	if (hisship == "NO Ship" ) then return end -- Don't send spots with no ships.
 	local whereat = ShortLocationStr(GetCurrentSectorid())
	if DeBug then print("Sending player spot: "..characteris.."  Guild: "..hisguild.." Ship: "..hisship.."  CharID: "..hischarid) end
	local mydata = {}
	table.insert(mydata,characteris)
	table.insert(mydata,hisguild)
	table.insert(mydata,hischarid)
	table.insert(mydata,whereat)
	table.insert(mydata,GetPlayerName(GetCharacterID()))
	table.insert(mydata,hisship)
	table.insert(mydata,tgft_utils.passwd)
	local senddata = json.encode( mydata )
	urlopen('http://www.tgft.org/vendetta/playerspot3.php', 'POST',tgft_utils.Server_Callback , {username=tgft_utils.user, passwd=tgft_utils.passwd, data=senddata})
 end

-------------------------------------------------------
-- Last Seen data 
-------------------------------------------------------
function tgft_utils.Lastseen(_, data)
if not data then return end
urlopen('http://www.tgft.org/vendetta/lastseenplayer.php', 'GET',tgft_utils.Server_Callback, {username=tgft_utils.user, passwd=tgft_utils.passwd, name=data[1]})
if DeBug then print("Lastseenplayer called") end
end

-------------------------------------------------------
-- Last Seen data in reverse order
-------------------------------------------------------
function tgft_utils.Lastseen2(_, data)
if not data then return end
urlopen('http://www.tgft.org/vendetta/lastseenplayer2.php', 'GET',tgft_utils.Server_Callback, {username=tgft_utils.user, passwd=tgft_utils.passwd, name=data[1]})
if DeBug then print("Lastseenplayer2 called") end
end

-------------------------------------------------------
-- Alt Finder
-------------------------------------------------------
function tgft_utils.Altfinder(_, data)
if not data then return end
if DeBug then print("Altfinder called") end
local senddata = json.encode( data )
urlopen('http://www.tgft.org/vendetta/altfinder.php', 'GET',tgft_utils.Server_Callback, {username=tgft_utils.user, passwd=tgft_utils.passwd, data=senddata})
end

LisaHeader={}
-------------------------------------------------------
-- Lastseen Server Call back function 
-------------------------------------------------------
function tgft_utils.Server_Callback_LastseenUI(not_ok, header, tgft_utils_page)
	if DeBug then print("LastseenUI Callback Fuction...") end
	local tgft_utils_srvdata	= {}
	LisaHeader=header
	if not_ok then
		tgft_utils.msg(tgft_utils_White,"ERROR1: "..not_ok)
	else
		if header.status == 200 then --Process what came back
		if DeBug then print("LastseenUI Fuction...") end
		local temp = string.gsub(tgft_utils_page,"[\r\n]","")
		else
			if DeBug then print("Header Status:"..header.status) end
			if header.status then
				tgft_utils.msg(tgft_utils_White,"ERROR2: Data Collector HTTP Error "..header.status)
			end
		end --Process what came back
	end
end

-------------------------------------------------------
-- Lookup Item Low System  
-------------------------------------------------------
function tgft_utils.LookupItemLowSystem(_, data)
if not data then return end
urlopen('http://www.tgft.org/vendetta/lookupitemlowstation.php', 'GET',tgft_utils.Server_Callback, {username=tgft_utils.user, passwd=tgft_utils.passwd, name=data[1],systemname=data[2]})
if DeBug then print("LookupStation called") end
end

-------------------------------------------------------
-- Lookup Item High System  
-------------------------------------------------------
function tgft_utils.LookupItemHighSystem(_, data)
if not data then return end
urlopen('http://www.tgft.org/vendetta/lookupitemhighstation.php', 'GET',tgft_utils.Server_Callback, {username=tgft_utils.user, passwd=tgft_utils.passwd, name=data[1],systemname=data[2]})
if DeBug then print("LookupStation called") end
end

-------------------------------------------------------
-- Server Call back function 
-------------------------------------------------------
function tgft_utils.Server_Callback(not_ok, header, tgft_utils_page)
if DeBug then print("Server_Callback Function...") end
local tgft_utils_srvdata	= {}
  if not_ok then
  	print("\127ffffffERROR1: "..not_ok)
  else
    if header.status == 200 then --Process what came back
  		for token in string.gmatch(tgft_utils_page, "[^\n]+") do --Convert to table
  			if token ~= "\r" then 
				table.insert(tgft_utils_srvdata,token) 
				print("\127ffffff"..token)
			end
		end   
  	else
		if header.status then
    		tgft_utils.msg(tgft_utils_White,"ERROR2: HTTP Error "..header.status)
		end
  	end --Process what came back
   end
end

-------------------------------------------------------
-- Sector Data Update 
-------------------------------------------------------
function tgft_utils.SectorUpdate(_, data)
	local secempty = 0
	local sectorid = GetCurrentSectorid()
	local secname = ShortLocationStr(sectorid)
	local secstorm = 0
	if IsStormPresent() then
		secstorm = 1
	end
	local botinfo = GetBotSightedInfoForSector(sectorid) or "N/A"
	botinfo = string.gsub(botinfo, "Bots Sighted: ", "") 
	local distance = radar.GetNearestObjectDistance()
	if distance == -1 then 
		secempty = 1
	end
	if DeBug then print("Sector Updated.") end
	urlopen('http://www.tgft.org/vendetta/sectordata.php', 'POST',tgft_utils.Server_Callback, {username=tgft_utils.user, passwd=tgft_utils.passwd, secempty=secempty,sectorid=sectorid,secname=secname,secstorm=secstorm,botinfo=botinfo,secempty=secempty})
end

-------------------------------------------------------
-- Search Items   
-------------------------------------------------------
function tgft_utils.SearchItems(_, data)
if not data then return end
urlopen('http://www.tgft.org/vendetta/searchitems.php', 'GET',tgft_utils.Server_Callback, {username=tgft_utils.user, passwd=tgft_utils.passwd, name=data[1]})
if DeBug then print("SearchItem called") end
end

-------------------------------------------------------
-- Lookup Item Low Price   
-------------------------------------------------------
function tgft_utils.LookupItemLow(_, data)
if not data then return end
urlopen('http://www.tgft.org/vendetta/lookupitemlow.php', 'GET',tgft_utils.Server_Callback, {username=tgft_utils.user, passwd=tgft_utils.passwd, name=data[1]})
if DeBug then print("LookupItemLow called") end
end

-------------------------------------------------------
-- Lookup Item High Price   
-------------------------------------------------------
function tgft_utils.LookupItemHigh(_, data)
if not data then return end
urlopen('http://www.tgft.org/vendetta/lookupitemhigh.php', 'GET',tgft_utils.Server_Callback, {username=tgft_utils.user, passwd=tgft_utils.passwd, name=data[1]})
if DeBug then print("LookupItemHigh called") end
end

-------------------------------------------------------
-- Lookup Station names and factions  
-------------------------------------------------------
function tgft_utils.Stations(_, data)
if not data then return end
urlopen('http://www.tgft.org/vendetta/stations.php', 'POST',tgft_utils.Server_Callback, {username=tgft_utils.user, passwd=tgft_utils.passwd, data=json.encode(data)})
if DeBug then print("Lookup Stations called") end
end

-------------------------------------------------------
-- Remove " from item names...
-------------------------------------------------------
function tgft_utils.RemQuote(data)
data = string.gsub(data, '"', '')
return data
end

-------------------------------------------------------
-- Station Buy Price Update
-------------------------------------------------------
function tgft_utils.BuyUpdate(_, data)
local stationid = GetStationLocation()
local stationsmarket = {}
for _,info in StationSellableInventoryPairs() do 
	local item = {}
	if (info.type ~= nil) then
		local onepcs = GetStationSellableInventoryPriceByID(info.itemid, 1)
		local many = GetStationSellableInventoryPriceByID(info.itemid, 1000000) / 1000000
		local static = 0
		if (onepcs==many) then -- Check for static price...
			static = 1
		end
		table.insert(item, stationid) -- 0
		table.insert(item, info.itemtype) -- 1 Really the ItemID
		local temp = tgft_utils.RemQuote(info.name)
		table.insert(item, temp) -- 2
		table.insert(item, info.type) -- 3
		table.insert(item, info.price) -- 4
		table.insert(item, static) -- 5
		table.insert(stationsmarket, item)		
	end
end
local senddata = json.encode( stationsmarket )
if DeBug then print("Stations Buy prices updated! ") end
urlopen('http://www.tgft.org/vendetta/stationbuyprice3.php', 'POST',tgft_utils.Server_Callback, {username=tgft_utils.user, passwd=tgft_utils.passwd, data=senddata})
end

-------------------------------------------------------
-- Station Update
-------------------------------------------------------
function tgft_utils.StationUpdate(_, data)
local item = {}
local sectorid = GetCurrentSectorid()
if DeBug then print("SectorID:"..sectorid) end
if (GetCurrentStationType() == 1) then return end
local stationid = GetStationLocation()
if DeBug then print("StationID:"..stationid) end
local name = GetStationName(stationid)
if DeBug then print("Name:"..name) end
local faction = GetStationFaction(stationid)
if DeBug then print("Faction:"..faction) end
table.insert(item,sectorid)
table.insert(item,stationid)
table.insert(item,name)
table.insert(item,faction)
item = json.encode( item )
urlopen('http://www.tgft.org/vendetta/stationinfo.php', 'POST',tgft_utils.Server_Callback, {username=tgft_utils.user, passwd=tgft_utils.passwd, data=item})
if DeBug then print("Station Data Updated.   stationinfo.php") end

local senddata = {}
for i=1, GetNumStationMerch() do 
	item = {}
	local info = GetStationMerchInfo(i)
	info.mass = tonumber(string.match(info.extendeddesc, "Mass: (%d+) kg") or 0)
	table.insert(item, info.itemid)
	table.insert(item, info.mass)
	table.insert(item, info.type)
	table.insert(item, info.volume)
	table.insert(item, info.name)
	table.insert(item, info.price)
	table.insert(item, stationid)
	table.insert(item, 0)
	table.insert(senddata, item)
end

local senddata = json.encode( senddata )
urlopen('http://www.tgft.org/vendetta/stationitems3.php', 'POST',tgft_utils.Server_Callback, {username=tgft_utils.user, passwd=tgft_utils.passwd, data=senddata})
if DeBug then print("Station Items Sold Updated.   stationitems.php") end
tgft_utils.BuyUpdate(_, data)
end

-------------------------------------------------------
-- Find my Trident
-------------------------------------------------------
function tgft_utils.FindDent(_, data)
	local items = {}
	for itemid,v in PlayerInventoryPairs() do
		local itemname = GetInventoryItemName(itemid)
		local stationid = GetInventoryItemLocation(itemid)
		local sectorid = SplitStationID(stationid)
		local itype = GetInventoryItemLongDesc(itemid) 
		if string.find(itype,"Trident Type") then 
			local location = ShortLocationStr(sectorid)
			if (location=="0 @-0") then
				print("-- Active Ship --")
				break
			end
			items = {itype=itype, location=location, itemname=itemname}
			print("\127ffffffYour dent is in: "..location.."   Navigation route set.")
			local location = string.match(location, '(%a+)').." "..string.match(location, '(%a%-%d+)')
			NavRoute.SetFinalDestination(SectorIDFromLocationStr(location))
		end
	end
end

-------------------------------------------------------
-- Find my Trident
-------------------------------------------------------
function tgft_utils.TargetDent(_, data)
	if (data) then
		tgft_utils.nodeid, tgft_utils.objectid = radar.GetRadarSelectionID()
		if DeBug then print("NodeID:"..tgft_utils.nodeid.."  ObjectID:"..tgft_utils.objectid) end
	else
		if (tgft_utils.nodeid > 0) and (tgft_utils.objectid > 0) then
			radar.SetRadarSelection(tgft_utils.nodeid, tgft_utils.objectid)
		end
	end
end

-------------------------------------------------------
-- Add an item to the guild list  
-------------------------------------------------------
function tgft_utils.GuildItem(_, data) -- command, qty, "item name"
if not data then 
	print("no data")
	return 
	end
local senddata = json.encode( data )
urlopen('http://www.tgft.org/vendetta/guilditem.php', 'POST',tgft_utils.Server_Callback, {username=tgft_utils.user, passwd=tgft_utils.passwd, data=senddata})
if DeBug then print("GuildItems called") end
end

-------------------------------------------------------
-- Unload cargo, and re-launch on docking event
-------------------------------------------------------
function tgft_utils.Unload2()
local shipinv = GetShipInventory(GetActiveShipID())
local cargolist = shipinv.cargo
local unloadlist = {}
for k,itemid in ipairs(cargolist) do
	local itemquantity = GetInventoryItemQuantity(itemid)
	if itemquantity then 
		table.insert(unloadlist, {itemid=itemid, quantity=itemquantity}) 
	end
end
CheckStorageAndUnloadCargo(unloadlist)
RequestLaunch()
end

-------------------------------------------------------
-- Unload cargo enable disable events
-------------------------------------------------------
function tgft_utils.Unload()
	if (tgft_utils.unload) then
	print("Auto Unload-Launch OFF")
	tgft_utils.unload = not tgft_utils.unload
	UnregisterEvent(tgft_utils.Unload2, "ENTERED_STATION")
	else
	print("Auto Unload-Launch ON")
	tgft_utils.unload = not tgft_utils.unload
	RegisterEvent(tgft_utils.Unload2, "ENTERED_STATION")
	end
end

-------------------------------------------------------
-- Modify KOS list
-------------------------------------------------------
function tgft_utils.KOS(_,data)
--if not data then return end
urlopen('http://www.tgft.org/vendetta/kos.php', 'POST',tgft_utils.Server_Callback, {username=tgft_utils.user, passwd=tgft_utils.passwd, data=json.encode(data)})
if DeBug then print("KOS called") end
end

-------------------------------------------------------
-- Modify App list
-------------------------------------------------------
function tgft_utils.App(_,data)
--if not data then return end
urlopen('http://www.tgft.org/vendetta/applicants.php', 'POST',tgft_utils.Server_Callback, {username=tgft_utils.user, passwd=tgft_utils.passwd, data=json.encode(data)})
if DeBug then print("KOS called") end
end

-------------------------------------------------------
-- Load list of stations.  Used for NAV
-------------------------------------------------------
function tgft_utils.GetStations()
urlopen('http://www.tgft.org/vendetta/liststations.php', 'POST',
function (not_ok, header, data)
	if DeBug then print("Internal liststations Callback Fuction...") end
	if not_ok then
		print("\127ffffffERROR1: "..not_ok)
	else
		if header.status == 200 then --Process what came back
			tgft_utils.stations=json.decode(data)
		else
			if header.status then
				tgft_utils.msg(tgft_utils_White,"ERROR2: HTTP Error "..header.status)
			end
		end --Process what came back
	end
end
,{username=tgft_utils.user, passwd=tgft_utils.passwd})
end

-------------------------------------------------------
-- Init
-------------------------------------------------------
function tgft_utils.Connection()
print("Connected...")
end

-------------------------------------------------------
-- Last Seen Data for UI
-------------------------------------------------------
function tgft_utils.LastSeenData(_, data)
if not data then return end
urlopen('http://www.tgft.org/vendetta/lastseendata.php', 'POST',tgft_utils.Server_Callback_LastseenUI, {username=tgft_utils.user, passwd=tgft_utils.passwd, data=json.encode(data)})
if DeBug then print("LastseenUI called") end
end

-------------------------------------------------------
-- Test function
-------------------------------------------------------
function tgft_utils.test(_, data)
--Scan system for sector data...

--GetBotSightedInfoForSector(int sectorid) -> string botinfo :: returns bot ihnfo text for the given sector
--GetSectorMonitoredStatus() -> int monitor :: returns the monitor status of the current sector (Unmonitored, Guarded ...)
--LocationStr(int sectorid) -> string sname :: translate a sectorid into a sector name. error if no argument provided
--SectorIDFromLocationStr(string location) -> int sectorid :: Convert a location string into a sectorid.
--SectorIDFromLocationStr("Sedina H-9") -> 5000

	--for k,v in pairs(_G) do
		--print("Global key", k, "value", v)
	--end

end

-------------------------------------------------------
-- Init
-------------------------------------------------------
function tgft_utils.Init()
	tgft_utils.passwd = gkini.ReadString("TGFT_Util","Password" ,"None")
	tgft_utils.user = GetPlayerName(GetCharacterID())
	if (tgft_utils.passwd == "None") then 
		math.randomseed(os.time())
		tgft_utils.passwd = tostring(math.random(10000, 99999))
		gkini.WriteString("TGFT_Util", "Password", tgft_utils.passwd)
		if DeBug then print("Your Password is:"..tgft_utils.passwd) end
	end
	local data = {}
	data[0] = tgft_utils.user
	data[1] = tgft_utils.passwd
	data[3] = {"this", "that"}
print("\127ffffffTGFT Utilities Version "..tgft_utils.version.."  Access Password: "..tgft_utils.passwd)

tgft_utils.GetStations()

UnregisterEvent(tgft_utils.Init, "HUD_SHOW")
UnregisterEvent(tgft_utils.Init, "SHOW_STATION")
RegisterEvent(tgft_utils.VerifyDestination, "SECTOR_LOADED")
--RegisterEvent(tgft_utils.VerifyDestination, "NAVROUTE_CHANGED")
tgft_utils.Get_Keychain()
end


function tgft_utils.uion()
tgft_utils.mydlg.mywindow:show()
end
function tgft_utils.uioff()
tgft_utils.mydlg.mywindow:hide()
end
-------------------------------------------------------
-- Commands the user can use in quotes
-------------------------------------------------------
RegisterUserCommand("search",tgft_utils.SearchItems);
RegisterUserCommand("lowprice",tgft_utils.LookupItemLow);
RegisterUserCommand("highprice",tgft_utils.LookupItemHigh);
RegisterUserCommand("mydent", tgft_utils.FindDent);
RegisterUserCommand("targetdent", tgft_utils.TargetDent);
RegisterUserCommand("stations",tgft_utils.Stations);
RegisterUserCommand("ispyr",tgft_utils.Lastseen2);
RegisterUserCommand("players",tgft_utils.Lastseen);
--RegisterUserCommand("ispyv",tgft_utils.Init);
RegisterUserCommand("altfinder",tgft_utils.Altfinder);
RegisterUserCommand("lastdata",tgft_utils.LastSeenData);

RegisterUserCommand("idebug", debugtoggle);
RegisterUserCommand("guilditem", tgft_utils.GuildItem);
RegisterUserCommand("lowsystem",tgft_utils.LookupItemLowSystem);
RegisterUserCommand("highsystem",tgft_utils.LookupItemHighSystem);

RegisterUserCommand("autounload",tgft_utils.Unload);
RegisterUserCommand("kos",tgft_utils.KOS);
RegisterUserCommand("app",tgft_utils.App);
RegisterUserCommand("turbotoggle",turbotoggle);
RegisterUserCommand("launch",tgft_utils.launch);

RegisterUserCommand("testkey",tgft_utils.Get_Keychain);
RegisterUserCommand("lisa",tgft_utils.uion);
RegisterUserCommand("lisax",tgft_utils.uioff);
RegisterUserCommand("itest",tgft_utils.test);

-------------------------------------------------------
-- register events 
-------------------------------------------------------
RegisterEvent(tgft_utils.SectorUpdate, "SECTOR_LOADED")
RegisterEvent(tgft_utils.StationUpdate, "ENTERED_STATION")
RegisterEvent(tgft_utils.Init, "HUD_SHOW")
RegisterEvent(tgft_utils.Init, "SHOW_STATION")
RegisterEvent(tgft_utils.Get_Keychain, "KEYADDED")
RegisterEvent(tgft_utils.Get_Keychain, "KEYREMOVED")
RegisterEvent(tgft_utils.SawPlayer, "PLAYER_ENTERED_SECTOR")
RegisterEvent(tgft_utils.SawPlayer, "SHIP_SPAWNED")
